@@ -1,7 +1,10 @@
 """Constants for the library."""
-
 from typing import Final
 
 ETS6_SCHEMA_VERSION: Final = "http://knx.org/xml/project/21"
 ETS57_SCHEMA_VERSION: Final = "http://knx.org/xml/project/20"
 ETS56_SCHEMA_VERSION: Final = "http://knx.org/xml/project/14"
+
+
+MAIN_DPT: Final = "DPT-"
+MAIN_AND_SUB_DPT: Final = "DPST-"
