@@ -4,8 +4,8 @@ from __future__ import annotations
 import logging
 
 from xknxproject import __version__
+from xknxproject.models import KNXProject
 from xknxproject.xml import XMLParser
-from xknxproject.xml.models import Area, GroupAddress
 from xknxproject.zip import KNXProjExtractor
 
 logger = logging.getLogger("xknxproject.log")
@@ -20,9 +20,7 @@ class KNXProj:
         self.parser = XMLParser(self.extractor)
         self.version = __version__
 
-    def parse(self) -> tuple[list[Area], list[GroupAddress]]:
+    async def parse(self) -> KNXProject:
         """Parse the KNX project."""
-        self.extractor.extract()
-        self.parser.parse()
-        self.extractor.cleanup()
-        return self.parser.areas, self.parser.group_addresses
+        with self.extractor:
+            return await self.parser.parse()
